summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browser.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/browser.cc')
-rw-r--r--chrome/browser/browser.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/browser.cc b/chrome/browser/browser.cc
index d20cd3f..8567bd0 100644
--- a/chrome/browser/browser.cc
+++ b/chrome/browser/browser.cc
@@ -431,12 +431,12 @@ SkBitmap Browser::GetCurrentPageIcon() const {
return contents ? contents->GetFavIcon() : SkBitmap();
}
-string16 Browser::GetCurrentPageTitle() const {
+string16 Browser::GetWindowTitleForCurrentTab() const {
TabContents* contents = tabstrip_model_.GetSelectedTabContents();
string16 title;
// |contents| can be NULL because GetCurrentPageTitle is called by the window
// during the window's creation (before tabs have been added).
if (contents) {
title = contents->GetTitle();
FormatTitleForDisplay(&title);
@@ -431,12 +431,12 @@ SkBitmap Browser::GetCurrentPageIcon() const {
TabContents* contents = tabstrip_model_.GetSelectedTabContents();
string16 title;
- // |contents| can be NULL because GetCurrentPageTitle is called by the window
- // during the window's creation (before tabs have been added).
+ // |contents| can be NULL because GetWindowTitleForCurrentTab is called by the
+ // window during the window's creation (before tabs have been added).
if (contents) {
title = contents->GetTitle();